import axios from 'axios';
import { provide, reactive } from 'vue';
import { useThemeLocaleData } from './useThemeData';
const articleData = reactive({
    counterList: [],
    counterTotal: 0,
    commentList: [],
    commentTotal: 0,
});
const articleDataSymbol = Symbol('articleData');
let themeLocale;
let headers = {};
// 访问相关
export const fetchCounter = () => {
    return new Promise((resolve, reject) => {
        if (themeLocale.value.comments?.counterUrl) {
            axios({
                method: 'get',
                url: themeLocale.value.comments.counterUrl,
                headers,
            })
                .then(function ({ data }) {
                resolve(data.results);
            })
                .catch((err) => reject(err));
        }
    });
};
// 评论相关
export const fetchComment = () => {
    return new Promise((resolve, reject) => {
        if (themeLocale.value.comments?.commentUrl) {
            axios({
                method: 'get',
                url: themeLocale.value.comments.commentUrl,
                headers,
            })
                .then(function ({ data }) {
                resolve(data.results);
            })
                .catch((err) => reject(err));
        }
    });
};
// 获取访问，评论相关数据
export const useArticleData = () => {
    return articleData;
};
export const setupArticleData = () => {
    // 先获取APP—ID和APP—KEY
    themeLocale = useThemeLocaleData();
    headers = {
        'X-LC-Id': themeLocale.value.comments?.['APP-ID'],
        'X-LC-Key': themeLocale.value.comments?.['APP-KEY'],
        'Content-Type': 'application/json',
    };
    fetchCounter().then((res) => {
        articleData.counterList = res;
        articleData.counterTotal = res.reduce((preVal, currVal) => preVal + currVal.time, 0);
    });
    fetchComment().then((res) => {
        articleData.commentList = res;
        articleData.commentTotal = res.length;
    });
    provide(articleDataSymbol, articleData);
};
