import { usePreferredDark, useStorage } from '@vueuse/core';
import { computed, inject, onMounted, onUnmounted, provide, watch } from 'vue';
import { useThemeLocaleData } from '.';
export const colorModeSymbol = Symbol(__VUEPRESS_DEV__ ? 'colorMode' : '');
export const useColorMode = () => {
    const isColorMode = inject(colorModeSymbol);
    if (!isColorMode) {
        throw new Error('useColorMode() is called without provider.');
    }
    return isColorMode;
};
/**
 * Create dark mode ref and provide as global computed in setup
 */
export const setupColorMode = () => {
    const themeLocale = useThemeLocaleData();
    const isDarkPreferred = usePreferredDark();
    const darkStorage = useStorage('vuepress-color-scheme', 'auto');
    const isColorMode = computed({
        get() {
            if (!themeLocale.value.colorMode) {
                return false;
            }
            if (darkStorage.value === 'auto') {
                return isDarkPreferred.value;
            }
            return darkStorage.value === 'dark';
        },
        set(val) {
            if (val === isDarkPreferred.value) {
                darkStorage.value = 'auto';
            }
            else {
                darkStorage.value = val ? 'dark' : 'light';
            }
        },
    });
    provide(colorModeSymbol, isColorMode);
    updateHtmlDarkClass(isColorMode);
};
export const updateHtmlDarkClass = (isColorMode) => {
    const update = (value = isColorMode.value) => {
        const htmlEl = window?.document.querySelector('html');
        htmlEl?.classList.toggle('dark', value);
    };
    onMounted(() => {
        watch(isColorMode, update, { immediate: true });
    });
    onUnmounted(() => update());
};
