"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBlogPlugin = void 0;
const vuepress_plugin_blog2_1 = require("vuepress-plugin-blog2");
const getTime = (page) => {
    const date = page.frontmatter.date;
    return date ? new Date(date).getTime() : -1;
};
const compareDate = (pageA, pageB) => {
    const timeA = getTime(pageA);
    const timeB = getTime(pageB);
    if (timeA === -1)
        return 1;
    if (timeB === -1)
        return -1;
    return timeB - timeA;
};
const sorter = (pageA, pageB) => compareDate(pageA, pageB);
const getBlogPlugin = (localeOptions, options) => {
    if (options === false)
        return [];
    return (0, vuepress_plugin_blog2_1.blogPlugin)({
        metaScope: '',
        filter: ({ filePathRelative }) => !!filePathRelative && filePathRelative.startsWith('posts/'),
        getInfo: ({ excerpt, frontmatter, }) => ({
            ...frontmatter,
            author: frontmatter.author,
            tags: frontmatter.tags || [],
            excerpt,
        }),
        category: [
            {
                key: 'tag',
                getter: ({ frontmatter }) => frontmatter.tags || [],
                path: '/tags/',
                layout: 'Tags',
                itemPath: '/tags/:name/',
                itemLayout: 'Tags',
                frontmatter: () => ({ title: 'Tags' }),
                itemFrontmatter: (name) => ({
                    title: `Tag ${name}`,
                }),
            },
        ],
        type: [
            {
                key: 'post',
                sorter,
                filter: () => true,
                path: '/',
                layout: 'HomePage',
                frontmatter: () => ({
                    title: 'Home',
                    layout: 'HomePage',
                }),
            },
        ],
    });
};
exports.getBlogPlugin = getBlogPlugin;
